<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.settings.landing.title") }}</DashboardTitle>
    </DashboardHeader>
    <SettingsBody>
      <template v-if="landingSettingsFetch.hasErrors">
        <ErrorState />
      </template>
      <template v-else>
        <FormGroup
          :is-loading="landingSettingsFetch.isFetching"
          @submit="submit"
        >
          <AlertError v-if="form.errors && form.errors?.unknown">
            {{ form.errors.unknown }}
          </AlertError>
          <FormSection>
            <FormInput
              id="hero_title"
              :errors="form.errors.hero_title"
            >
              <FormLabel>{{ $t("app.admin.settings.landing.form.hero_title") }}</FormLabel>
              <FormText
                v-model="form.values.hero_title"
                name="hero_title"
                required
              />
            </FormInput>
            <FormInput
              id="hero_subtitle"
              :errors="form.errors.hero_subtitle"
            >
              <FormLabel>{{ $t("app.admin.settings.landing.form.hero_subtitle") }}</FormLabel>
              <FormText
                v-model="form.values.hero_subtitle"
                name="hero_subtitle"
              />
            </FormInput>
            <FormInput
              id="link_shortening"
              :errors="form.errors.link_shortening"
            >
              <FormSwitch
                v-model="form.values.link_shortening"
                description="app.admin.settings.landing.form.link_shortening.description"
                label="app.admin.settings.landing.form.link_shortening.label"
                name="link_shortening"
                required
              />
            </FormInput>
          </FormSection>
          <div>
            <FormSubmit
              :processing="form.isFetching"
              class="btn btn-black"
            >
              {{ $t("app.admin.settings.submit") }}
            </FormSubmit>
          </div>
        </FormGroup>
      </template>
    </SettingsBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import useNotification from "@/js/contexts/shared/composables/useNotification";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import SettingsBody from "@/js/contexts/admin/settings/ui/components/SettingsBody.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import ErrorState from "@/js/contexts/shared/ui/components/error/ErrorState.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import FormSwitch from "@/js/contexts/form/ui/components/FormSwitch.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";

type Response = {
  hero_title: string;
  hero_subtitle: string;
  link_shortening: boolean;
};

const { t } = useI18n();
const { successNotification } = useNotification();

useHead({
  title: t("app.admin.settings.landing.title"),
});

const landingSettingsFetch = useFetch("/api/admin/settings/landing", { isFetching: true });

const form = useForm({
  hero_title: "",
  hero_subtitle: "",
  link_shortening: true,
});

onMounted(() => {
  landingSettingsFetch.get<Response>().then((response) => {
    form.values.hero_title = response.data.hero_title;
    form.values.hero_subtitle = response.data.hero_subtitle;
    form.values.link_shortening = response.data.link_shortening;
    form.updatedValues();
  });
});

const submit = () => {
  form.post("/api/admin/settings/landing", {
    onSuccess: () => successNotification(t("app.admin.settings.success")),
  });
};
</script>
